Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(271)

Unified Diff: media/video/capture/screen/screen_capture_frame_queue.h

Issue 13983010: Use webrtc::DesktopCapturer for screen capturer implementation. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/video/capture/screen/screen_capture_frame_queue.h
diff --git a/media/video/capture/screen/screen_capture_frame_queue.h b/media/video/capture/screen/screen_capture_frame_queue.h
index d36f15a462501a2b7b403015e8ee3ac2ed5b6c50..c51c563f5bff67e25818ee52488c531e434ccda7 100644
--- a/media/video/capture/screen/screen_capture_frame_queue.h
+++ b/media/video/capture/screen/screen_capture_frame_queue.h
@@ -7,20 +7,27 @@
#include "base/compiler_specific.h"
#include "base/memory/scoped_ptr.h"
+#include "media/video/capture/screen/shared_desktop_frame.h"
-namespace media {
+namespace webrtc {
+class DesktopFrame;
+} // namespace webrtc
-class ScreenCaptureFrame;
+namespace media {
// Represents a queue of reusable video frames. Provides access to the 'current'
// frame - the frame that the caller is working with at the moment, and to
// the 'previous' frame - the predecessor of the current frame swapped by
// DoneWithCurrentFrame() call, if any.
//
-// The caller is expected to (re)allocate frames if current_frame_needs_update()
-// is set. The caller can mark all frames in the queue for reallocation (when,
-// say, frame dimensions change). The queue records which frames need updating
+// The caller is expected to (re)allocate frames if current_frame() returns
+// NULL. The caller can mark all frames in the queue for reallocation (when,
+// say, frame dimensions change). The queue records which frames need updating
// which the caller can query.
+//
+// Frame consumer is expected to never hold more than kQueueLength frames
+// created by this function and it should release the earliest one before trying
+// to capture a new frame (i.e. before MoveToNextFrame() is called).
class ScreenCaptureFrameQueue {
public:
ScreenCaptureFrameQueue();
@@ -28,38 +35,30 @@ class ScreenCaptureFrameQueue {
// Moves to the next frame in the queue, moving the 'current' frame to become
// the 'previous' one.
- void DoneWithCurrentFrame();
+ void MoveToNextFrame();
// Replaces the current frame with a new one allocated by the caller.
// The existing frame (if any) is destroyed.
- void ReplaceCurrentFrame(scoped_ptr<ScreenCaptureFrame> frame);
+ void ReplaceCurrentFrame(scoped_ptr<webrtc::DesktopFrame> frame);
// Marks all frames obsolete and resets the previous frame pointer. No
// frames are freed though as the caller can still access them.
- void SetAllFramesNeedUpdate();
+ void Reset();
- ScreenCaptureFrame* current_frame() const {
+ SharedDesktopFrame* current_frame() const {
return frames_[current_].get();
}
- bool current_frame_needs_update() const {
- return !current_frame() || needs_update_[current_];
+ SharedDesktopFrame* previous_frame() const {
+ return frames_[(current_ + kQueueLength - 1) % kQueueLength].get();
}
- ScreenCaptureFrame* previous_frame() const { return previous_; }
-
private:
// Index of the current frame.
int current_;
static const int kQueueLength = 2;
- scoped_ptr<ScreenCaptureFrame> frames_[kQueueLength];
-
- // True if the corresponding frame needs to be re-allocated.
- bool needs_update_[kQueueLength];
-
- // Points to the previous frame if any.
- ScreenCaptureFrame* previous_;
+ scoped_ptr<SharedDesktopFrame> frames_[kQueueLength];
DISALLOW_COPY_AND_ASSIGN(ScreenCaptureFrameQueue);
};
« no previous file with comments | « media/video/capture/screen/screen_capture_frame.cc ('k') | media/video/capture/screen/screen_capture_frame_queue.cc » ('j') | no next file with comments »
@@ -7,20 +7,27 @@
// Represents a queue of reusable video frames. Provides access to the 'current'
-// frame - the frame that the caller is working with at the moment, and to
-// the 'previous' frame - the predecessor of the current frame swapped by
-// DoneWithCurrentFrame() call, if any.
+// frame - the frame that the caller is working with at the moment, and to the
+// 'previous' frame - the predecessor of the current frame swapped by
+// MoveToNextFrame() call, if any.
//

Powered by Google App Engine
This is Rietveld 408576698